package com.ruoyi.manage.mapper;

import java.util.List;
import com.ruoyi.manage.domain.RecordInvalidated;
import org.springframework.stereotype.Repository;
/**
 * 轮挡报废记录Mapper接口
 *
 * @author wangh
 * @date 2024-01-26
 */
@Repository
public interface RecordInvalidatedMapper
{
    /**
     * 查询轮挡报废记录
     *
     * @param objid 轮挡报废记录主键
     * @return 轮挡报废记录
     */
    public RecordInvalidated selectRecordInvalidatedByObjid(Long objid);

    /**
     * 查询轮挡报废记录列表
     *
     * @param recordInvalidated 轮挡报废记录
     * @return 轮挡报废记录集合
     */
    public List<RecordInvalidated> selectRecordInvalidatedList(RecordInvalidated recordInvalidated);

    /**
     * 新增轮挡报废记录
     *
     * @param recordInvalidated 轮挡报废记录
     * @return 结果
     */
    public int insertRecordInvalidated(RecordInvalidated recordInvalidated);

    /**
     * 修改轮挡报废记录
     *
     * @param recordInvalidated 轮挡报废记录
     * @return 结果
     */
    public int updateRecordInvalidated(RecordInvalidated recordInvalidated);

    /**
     * 删除轮挡报废记录
     *
     * @param objid 轮挡报废记录主键
     * @return 结果
     */
    public int deleteRecordInvalidatedByObjid(Long objid);

    /**
     * 批量删除轮挡报废记录
     *
     * @param objids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordInvalidatedByObjids(String[] objids);
}
