package com.ruoyi.manage.controller;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.manage.domain.RecordInvalidated;
import com.ruoyi.manage.service.IRecordInvalidatedService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 轮挡报废记录Controller
 * 
 * @author wangh
 * @date 2024-01-26
 */
@Controller
@RequestMapping("/manage/record_invalidated")
public class RecordInvalidatedController extends BaseController
{
    private String prefix = "manage/record_invalidated";

    @Autowired
    private IRecordInvalidatedService recordInvalidatedService;

    @RequiresPermissions("manage:record_invalidated:view")
    @GetMapping()
    public String record_invalidated()
    {
        return prefix + "/record_invalidated";
    }

    /**
     * 查询轮挡报废记录列表
     */
    @RequiresPermissions("manage:record_invalidated:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(RecordInvalidated recordInvalidated)
    {
        startPage();
        List<RecordInvalidated> list = recordInvalidatedService.selectRecordInvalidatedList(recordInvalidated);
        return getDataTable(list);
    }

    /**
     * 导出轮挡报废记录列表
     */
    @RequiresPermissions("manage:record_invalidated:export")
    @Log(title = "轮挡报废记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(RecordInvalidated recordInvalidated)
    {
        List<RecordInvalidated> list = recordInvalidatedService.selectRecordInvalidatedList(recordInvalidated);
        ExcelUtil<RecordInvalidated> util = new ExcelUtil<RecordInvalidated>(RecordInvalidated.class);
        return util.exportExcel(list, "轮挡报废记录数据");
    }

    /**
     * 新增轮挡报废记录
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存轮挡报废记录
     */
    @RequiresPermissions("manage:record_invalidated:add")
    @Log(title = "轮挡报废记录", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(RecordInvalidated recordInvalidated)
    {
        return toAjax(recordInvalidatedService.insertRecordInvalidated(recordInvalidated));
    }

    /**
     * 修改轮挡报废记录
     */
    @RequiresPermissions("manage:record_invalidated:edit")
    @GetMapping("/edit/{objid}")
    public String edit(@PathVariable("objid") Long objid, ModelMap mmap)
    {
        RecordInvalidated recordInvalidated = recordInvalidatedService.selectRecordInvalidatedByObjid(objid);
        mmap.put("recordInvalidated", recordInvalidated);
        return prefix + "/edit";
    }

    /**
     * 修改保存轮挡报废记录
     */
    @RequiresPermissions("manage:record_invalidated:edit")
    @Log(title = "轮挡报废记录", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(RecordInvalidated recordInvalidated)
    {
        return toAjax(recordInvalidatedService.updateRecordInvalidated(recordInvalidated));
    }

    /**
     * 删除轮挡报废记录
     */
    @RequiresPermissions("manage:record_invalidated:remove")
    @Log(title = "轮挡报废记录", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(recordInvalidatedService.deleteRecordInvalidatedByObjids(ids));
    }
}
